aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLilly Rose Berner <[email protected]>2021-06-06 23:31:32 +0200
committerGitHub <[email protected]>2021-06-06 17:31:32 -0400
commitfb0c6c56e12b539e2ed1dead3c66da97dec3804d (patch)
treea67efb8391e8017fdb10d4fea1b98a0eed39ffd3
parentAdd pre-conditions to avoid on_timeout being called after stop() (diff)
downloaddiscord.py-fb0c6c56e12b539e2ed1dead3c66da97dec3804d.tar.xz
discord.py-fb0c6c56e12b539e2ed1dead3c66da97dec3804d.zip
Return message content for replies in Message.system_content
-rw-r--r--discord/message.py9
1 files changed, 6 insertions, 3 deletions
diff --git a/discord/message.py b/discord/message.py
index ca70c71c..42ef6bf7 100644
--- a/discord/message.py
+++ b/discord/message.py
@@ -975,9 +975,9 @@ class Message(Hashable):
r""":class:`str`: A property that returns the content that is rendered
regardless of the :attr:`Message.type`.
In the case of :attr:`MessageType.default`\, this just returns the
regular :attr:`Message.content`. Otherwise this returns an English
message denoting the contents of the system message.
"""
if self.type is MessageType.default:
@@ -1048,6 +1048,9 @@ class Message(Hashable):
if self.type is MessageType.guild_discovery_grace_period_final_warning:
return 'This server has failed Discovery activity requirements for 3 weeks in a row. If this server fails for 1 more week, it will be removed from Discovery.'
+ if self.type is MessageType.reply:
+ return self.content
+
if self.type is MessageType.guild_invite_reminder:
return 'Wondering who to invite?\nStart by inviting anyone who can help you build the server!'
@@ -975,9 +975,9 @@ class Message(Hashable):
r""":class:`str`: A property that returns the content that is rendered
regardless of the :attr:`Message.type`.
- In the case of :attr:`MessageType.default`\, this just returns the
- regular :attr:`Message.content`. Otherwise this returns an English
- message denoting the contents of the system message.
+ In the case of :attr:`MessageType.default` and :attr:`MessageType.reply`\,
+ this just returns the regular :attr:`Message.content`. Otherwise this
+ returns an English message denoting the contents of the system message.
"""
if self.type is MessageType.default: